@@ -310,27 +310,52 @@ def make_tex_document_1(
     import numpy as np
     import matplotlib.pyplot as plt
     import matplotlib
+    import matplotlib.cm as cmx
     from pathlib import Path
     import os
+    
+    from .image_features_extract import read_plu_topography, fill_gap
 
     size_min = 50
     alpha1 = 0.35
     alpha2 = 0.8
 
-    print(param["file"])
-    n_row, n_col = np.shape(im_brute)
 
     fig = plt.figure(figsize=(8, 8))
-    ax1 = fig.add_subplot(111)
-    ax1.imshow(im_brute, interpolation="nearest", cmap=plt.cm.gray)
+    N, M, confocal_img, rgb = read_plu_topography(param['repertoire']/param['file'])
+
+    confocal_img1 = fill_gap(confocal_img)
+    plt.imshow(confocal_img1, cmap='gray')
+    plt.colorbar()
+    mask = np.where(confocal_img == 1000001)
+    plt.scatter(mask[1],mask[0],c='r',s =1,alpha=0.1 )
 
     file_save_im_brute = Path(param["file"]).stem + "-im-brute.jpg"
     plt.savefig(param["dir_results"] / file_save_im_brute, bbox_inches="tight")
     plt.close(fig)
 
     fig = plt.figure(figsize=(8, 8))
-    ax1 = fig.add_subplot(111)
-    ax1.imshow(im_bin, interpolation="nearest", cmap=plt.cm.gray)
+    colorsMap = plt.get_cmap("plasma") #("RdYlGn")
+    g = list(zip(np.array(df['x']),
+                 np.array(df['y']),
+                 np.array(df['height']),
+                 np.array(df['size'])))
+    x,y,c,s=zip(*sorted(g, key=lambda tup: tup[2],reverse=False))
+
+    cm = plt.get_cmap(colorsMap)
+    cNorm = matplotlib.colors.Normalize(vmin=min(c), vmax=max(c))
+    scalarMap = cmx.ScalarMappable(norm=cNorm, cmap=cm)
+
+    plt.scatter(np.array(y) ,N-np.array(x) ,s=np.array(s)/5, c=scalarMap.to_rgba(c))
+    plt.xlim(0,M)
+    plt.ylim(0,N)
+    scalarMap.set_array(c)
+
+    trash = plt.yticks(ticks=[N,N-100, N-200, N-300, N-400, N-500],labels=[0,100,200,300,400,500],
+                                   rotation=0)
+    plt.colorbar(scalarMap)
+
+    
     file_save_im_bin = Path(param["file"]).stem + "-im-bin.jpg"
     plt.savefig(param["dir_results"] / file_save_im_bin, bbox_inches="tight")
     plt.close(fig)
@@ -351,7 +376,7 @@ def make_tex_document_1(
     plt.close(fig)
 
     file_save_doc_tex = Path(param["file"]).stem + "_doc_tex.tex"
-    with open(param["dir_tex"] / Path("rapport.tex"), mode) as doc:
+    with open(param["dir_tex"] / Path('rapport_'+param['coupe']+'.tex'), mode) as doc:
         if mode == "w":
             doc.write(
                 r"""\documentclass[a4paper, 10pt]{article}
@@ -426,10 +451,9 @@ def make_tex_document_1(
         doc.write(
             r"""\end{tabular}
         \end{center}
-        \caption{Image processing: (a) Superposition of the flattened image with the detected defaults, the erea of the circles
-        are equal to the erea of the defaults, the green circle have an area less than 50 px, the blue one have area greater or
-        equal than 50 px
-        ; (b) Binarized image; (c) Area histogram; (d) Box plot of the area.}
+        \caption{Image processing: (a) Superposition of the confocal topographic image with non measured pixels (in red)
+        ; (b) Image of the extracted features where the sizes of the cicles are proportional to the features area 
+        and where the color of the circles are related to the features depth; (c) Area histogram; (d) Box plot of the area.}
         \end{figure}"""
             + "\n"
         )
